'use client';

import { useState } from 'react';
import { usePathname, useRouter } from 'next/navigation';
import { motion, AnimatePresence } from 'framer-motion';
import { 
  FiBook, 
  FiUsers, 
  FiSettings, 
  FiBarChart2, 
  FiGrid,
  FiAward,
  FiHelpCircle,
  FiMenu,
  FiX
} from 'react-icons/fi';

const sidebarItems = [
  {
    title: 'Overview',
    icon: <FiGrid className="w-5 h-5" />,
    path: '/admin',
    group: 'main'
  },
  {
    title: 'Educational Content',
    icon: <FiBook className="w-5 h-5" />,
    path: '/admin/content',
    group: 'content',
    subItems: [
      { title: 'Subjects', path: '/admin/content/subjects' },
      { title: 'Topics', path: '/admin/content/topics' },
      { title: 'Lessons', path: '/admin/content/lessons' },
      { title: 'Quizzes', path: '/admin/content/quizzes' }
    ]
  },
  {
    title: 'Users',
    icon: <FiUsers className="w-5 h-5" />,
    path: '/admin/users',
    group: 'users',
    subItems: [
      { title: 'Students', path: '/admin/users/students' },
      { title: 'Teachers', path: '/admin/users/teachers' },
      { title: 'Admins', path: '/admin/users/admins' }
    ]
  },
  {
    title: 'Games',
    icon: <FiAward className="w-5 h-5" />,
    path: '/admin/games',
    group: 'games',
    subItems: [
      { title: 'Game List', path: '/admin/games/list' },
      { title: 'Statistics', path: '/admin/games/stats' },
      { title: 'Achievements', path: '/admin/games/achievements' }
    ]
  },
  {
    title: 'Analytics',
    icon: <FiBarChart2 className="w-5 h-5" />,
    path: '/admin/analytics',
    group: 'analytics'
  },
  {
    title: 'Settings',
    icon: <FiSettings className="w-5 h-5" />,
    path: '/admin/settings',
    group: 'settings'
  },
  {
    title: 'Support',
    icon: <FiHelpCircle className="w-5 h-5" />,
    path: '/admin/support',
    group: 'support'
  }
];

export default function AdminLayout({
  children
}: {
  children: React.ReactNode;
}) {
  const [isSidebarOpen, setIsSidebarOpen] = useState(true);
  const [expandedGroup, setExpandedGroup] = useState<string | null>(null);
  const pathname = usePathname();
  const router = useRouter();

  const toggleSidebar = () => setIsSidebarOpen(!isSidebarOpen);
  
  const handleNavigation = (path: string, group: string) => {
    router.push(path);
    if (group) {
      setExpandedGroup(expandedGroup === group ? null : group);
    }
  };

  return (
    <div className="flex h-screen bg-[#0a0a0a]">
      {/* Mobile Sidebar Toggle */}
      <button
        className="lg:hidden fixed top-4 left-4 z-50 p-2 bg-[#1a1a1a] rounded-md shadow-md text-[#FF6B2B]"
        onClick={toggleSidebar}
      >
        {isSidebarOpen ? (
          <FiX className="w-6 h-6" />
        ) : (
          <FiMenu className="w-6 h-6" />
        )}
      </button>

      {/* Sidebar */}
      <AnimatePresence mode="wait">
        {isSidebarOpen && (
          <motion.aside
            initial={{ x: -300 }}
            animate={{ x: 0 }}
            exit={{ x: -300 }}
            className={`fixed lg:static inset-y-0 left-0 z-40 w-64 bg-[#1a1a1a] shadow-lg transform 
              transition-transform duration-300 ease-in-out lg:translate-x-0
              ${isSidebarOpen ? 'translate-x-0' : '-translate-x-full'}`}
          >
            <div className="flex flex-col h-full">
              {/* Logo */}
              <div className="flex items-center justify-center h-16 bg-[#FF6B2B]">
                <img 
                  src="/edvolab_logo.png" 
                  alt="Logo" 
                  className="h-10 w-auto"
                />
              </div>

              {/* Navigation */}
              <nav className="flex-1 overflow-y-auto py-4">
                {sidebarItems.map((item) => (
                  <div key={item.path} className="px-4 py-2">
                    <div
                      className={`flex items-center justify-between px-4 py-2 rounded-md cursor-pointer
                        ${pathname === item.path 
                          ? 'bg-[#FF6B2B] text-white' 
                          : 'text-gray-300 hover:bg-[#2a2a2a] hover:text-white'}`}
                      onClick={() => handleNavigation(item.path, item.group)}
                    >
                      <div className="flex items-center flex-1">
                        <span className={pathname === item.path ? 'text-white' : 'text-[#FF6B2B]'}>
                          {item.icon}
                        </span>
                        <span className="ml-3">{item.title}</span>
                      </div>
                      {item.subItems && (
                        <motion.span
                          animate={{ rotate: expandedGroup === item.group ? 180 : 0 }}
                          className={`ml-2 ${pathname === item.path ? 'text-white' : 'text-[#FF6B2B]'}`}
                        >
                          ▼
                        </motion.span>
                      )}
                    </div>

                    {/* SubItems */}
                    <AnimatePresence>
                      {item.subItems && expandedGroup === item.group && (
                        <motion.div
                          initial={{ height: 0, opacity: 0 }}
                          animate={{ height: 'auto', opacity: 1 }}
                          exit={{ height: 0, opacity: 0 }}
                          className="ml-8 mt-2 space-y-1"
                        >
                          {item.subItems.map((subItem) => (
                            <div
                              key={subItem.path}
                              onClick={() => router.push(subItem.path)}
                              className={`block px-4 py-2 text-sm rounded-md cursor-pointer
                                ${pathname === subItem.path 
                                  ? 'bg-[#FF6B2B]/20 text-[#FF6B2B]' 
                                  : 'text-gray-300 hover:bg-[#2a2a2a] hover:text-white'}`}
                            >
                              {subItem.title}
                            </div>
                          ))}
                        </motion.div>
                      )}
                    </AnimatePresence>
                  </div>
                ))}
              </nav>

              {/* User Profile Section */}
              <div className="p-4 border-t border-[#2a2a2a]">
                <div className="flex items-center space-x-3 text-gray-300">
                  <div className="w-8 h-8 rounded-full bg-[#FF6B2B] flex items-center justify-center">
                    <span className="text-white text-sm">A</span>
                  </div>
                  <div className="flex-1 min-w-0">
                    <p className="text-sm font-medium truncate">Admin</p>
                    <p className="text-xs text-gray-500 truncate">admin@nomvate.com</p>
                  </div>
                  <button 
                    onClick={() => router.push('/admin/settings')}
                    className="p-1 rounded-full hover:bg-[#2a2a2a]"
                  >
                    <FiSettings className="w-4 h-4 text-[#FF6B2B]" />
                  </button>
                </div>
              </div>
            </div>
          </motion.aside>
        )}
      </AnimatePresence>

      {/* Main Content */}
      <main className="flex-1 overflow-x-hidden overflow-y-auto bg-[#0a0a0a] text-white">
        <div className="container mx-auto px-6 py-8">
          {children}
        </div>
      </main>
    </div>
  );
} 